==> ICA-1.5.tar.gz: ICA-1.5/src/RETAG/Insert/signal.c <==
/* CONTENTS
   Owner:       Copyright 1990 The Ohio State University,
                Integrated Chameleon Architecture
   Module:      $RCSfile: signal.c,v $
   Purpose:     
       Provide signal handlers in case of an error in the program.

   Programmer:  Conleth O'Connell
   Reviewer:    
   Revision:    $Revision: 1.4 $
   Date:        $Date: 92/05/20 11:33:55 $

   Functions Index:
   AVAIL   NAME DEPENDS ON INTERNALLY      EXTERNALLY
   -----   ----            ----------      ----------
   HIDDEN  FileDump
                                           SaveFile
   HIDDEN  HandleSignal
                           FileDump
   EXPORT  InstallSignalHandlers
*/

/* HISTORY
   $Log:	signal.c,v $
 * Revision 1.4  92/05/20  11:33:55  ware
 * Removed unnecessary parameter from signal()
 * 
 * Revision 1.3  92/03/16  13:53:43  ware
 * Make titles consistent.  Fix some consistency problems.
 * 
 * Revision 1.2  1992/01/28  22:36:50  cso
 * Restructured dependencies
 *
 * Revision 1.1.1.3  1991/10/04  20:18:55  jbm
 * First HaL mods to ICA
 *
 * Revision 2.0  91/03/30  13:52:38  cso
 * This module is now in Alpha Release form.
 * 
 * Revision 1.4  91/03/28  14:47:50  cso
 * Added the FileDump to even unrecognized signals.
 * 
 * Revision 1.3  91/02/22  09:58:53  cso
 * Completed documentation.
 * Added a FileDump function to handle opening a file dumping 
 * the grammar information and closing the file for any
 * 	of the signal handlers to use.
 * 
 * Revision 1.2  90/11/20  15:55:55  cso
 * Cosmetic changes and changed the return to an exit call.
 * 
 * Revision 1.1  90/11/05  18:26:58  cso
 * Initial revision
 * 
*/

/* #INCLUDES */

#include <signal.h>
#include "widgets.h"
#include "defs.h"
#include "types.h"

/* External globals */


/* External routines */

#include "itool.h"



/*
   FUNCTION: 		FileDump

   Synopsis: 
       Dump the present grammar into a file and inform the user.

   Initial purpose:
       Same as above.

   Present purpose:
       Same as above.

   Creator:	Conleth O'Connell
   Reviewer:	

   Modifications:
       DATE     WHO      REASON

   System files modified:
       Taking advantage of write access to /tmp.  In general this may not
       work.

   Globals used:
       Root     To access the top of the tree and generate the grammar

   Globals Modified:
       none

   Return value:	void

   Range:		none
*/

static void
FileDump()

{
   FILE
      *fptr; /* File pointer to dump the present grammar */

   /*
    * Attempt to open a file,
    * If not allowed to do so, inform the user
    * Else generate a devegram file and inform the user where it is
    */
   fptr = fopen("/tmp/dump.isf", "w");
   if (fptr == NULL)
   {
      fprintf(stderr, "Unable to open /tmp/dump.dgm\n");
      fprintf(stderr, "Failing without recourse\n");
   }
   else
   {
      SaveIspec(fptr);
      fclose(fptr);
      fprintf(stderr, "The isf can be found in /tmp/dump.isf\n");
   }
}




/*
   FUNCTION: 		HandleSignal

   Synopsis: 
       To provide a graceful means of dying by at least saving out 
       any changes to a grammar.

   Initial purpose:
       Same as above.

   Present purpose:
       Same as above.

   Creator:	Conleth O'Connell
   Reviewer:	

   Modifications:
       DATE       WHO    REASON
       91/03/08   cso    Dump the grammar even if I don't recognize
                          the signal.

   Globals used:
       none

   Globals Modified:
       none

   Return value:	static void

   Range:		none
*/

static void
HandleSignal(sig)

int
   sig;           /* The signal needing handling */

{
   /*
    * Depending on the signal, handle it
    */
   switch (sig)
   {
   default:
      /*
       * This signal is not handled
       */
      fprintf(stderr, "Didn't match anybody\n");
      FileDump();
      break;

   case SIGSEGV:
      /*
       * This is a segmentation violation, dump the grammar
       */
      fprintf(stderr, "Received a Segmentation Violation signal\n");
      FileDump();
      break;

   case SIGBUS:
      /*
       * This is a bus error, dump the grammar
       */
      fprintf(stderr, "Received a Bus error signal\n");
      FileDump();
      break;

   case SIGHUP:
      /*
       * This signal is not handled
       */
      fprintf(stderr, "Received a HangUp signal\n");
      break;

   case SIGINT:
      /*
       * This signal is not handled
       */
      fprintf(stderr, "Received a Ctrl-C signal\n");
      break;
   }
   exit(2);
}




/*
   FUNCTION: 		InstallSignalHandlers

   Synopsis: 
       Install the signal handler for certain types of signals.

   Initial purpose:
       Same as above.

   Present purpose:
       Same as above.

   Creator:	Conleth O'Connell
   Reviewer:	

   Modifications:
       DATE       WHO    REASON

   Globals used:
       none

   Globals Modified:
       none

   Return value:	void

   Range:		none
*/

void
InstallSignalHandlers()

{
   /*
    * As the installation occurs, check for an error, inform the user
    * if installation of any of the signals have failed
    */
   if ((signal(SIGBUS,  HandleSignal) == SIG_ERR) ||
       (signal(SIGHUP,  HandleSignal) == SIG_ERR) ||
       (signal(SIGINT,  HandleSignal) == SIG_ERR) ||
       (signal(SIGSEGV, HandleSignal) == SIG_ERR))
   {
      fprintf(stderr, "Not all signal() handlers were installed\n");
   }
   return;
}

==> ICA-1.6.tar.gz: ICA-1.6/src/RETAG/Insert/signal.c <==
/* CONTENTS
   Owner:       Copyright 1990 The Ohio State University,
                Integrated Chameleon Architecture
   Module:      signal.c,v
   Purpose:     
       Provide signal handlers in case of an error in the program.

   Programmer:  Conleth O'Connell
   Reviewer:    
   Revision:    1.5
   Date:        1993/04/19 17:10:38

   Functions Index:
   AVAIL   NAME DEPENDS ON INTERNALLY      EXTERNALLY
   -----   ----            ----------      ----------
   HIDDEN  FileDump
                                           SaveFile
   HIDDEN  HandleSignal
                           FileDump
   EXPORT  InstallSignalHandlers
*/

/* HISTORY
   signal.c,v
 * Revision 1.5  1993/04/19  17:10:38  ware
 * Merged John Boyds changes.
 *
 * Revision 1.4  92/05/20  11:33:55  ware
 * Removed unnecessary parameter from signal()
 * 
 * Revision 1.3  92/03/16  13:53:43  ware
 * Make titles consistent.  Fix some consistency problems.
 * 
 * Revision 1.2  1992/01/28  22:36:50  cso
 * Restructured dependencies
 *
 * Revision 1.1.1.3  1991/10/04  20:18:55  jbm
 * First HaL mods to ICA
 *
 * Revision 2.0  91/03/30  13:52:38  cso
 * This module is now in Alpha Release form.
 * 
 * Revision 1.4  91/03/28  14:47:50  cso
 * Added the FileDump to even unrecognized signals.
 * 
 * Revision 1.3  91/02/22  09:58:53  cso
 * Completed documentation.
 * Added a FileDump function to handle opening a file dumping 
 * the grammar information and closing the file for any
 * 	of the signal handlers to use.
 * 
 * Revision 1.2  90/11/20  15:55:55  cso
 * Cosmetic changes and changed the return to an exit call.
 * 
 * Revision 1.1  90/11/05  18:26:58  cso
 * Initial revision
 * 
*/

/* #INCLUDES */

#include <signal.h>
#include "widgets.h"
#include "defs.h"
#include "types.h"

/* External globals */


/* External routines */

#include "itool.h"



/*
   FUNCTION: 		FileDump

   Synopsis: 
       Dump the present grammar into a file and inform the user.

   Initial purpose:
       Same as above.

   Present purpose:
       Same as above.

   Creator:	Conleth O'Connell
   Reviewer:	

   Modifications:
       DATE     WHO      REASON

   System files modified:
       Taking advantage of write access to /tmp.  In general this may not
       work.

   Globals used:
       Root     To access the top of the tree and generate the grammar

   Globals Modified:
       none

   Return value:	void

   Range:		none
*/

static void
FileDump()

{
   FILE
      *fptr; /* File pointer to dump the present grammar */

   /*
    * Attempt to open a file,
    * If not allowed to do so, inform the user
    * Else generate a devegram file and inform the user where it is
    */
   fptr = fopen("/tmp/dump.isf", "w");
   if (fptr == NULL)
   {
      fprintf(stderr, "Unable to open /tmp/dump.dgm\n");
      fprintf(stderr, "Failing without recourse\n");
   }
   else
   {
      SaveIspec(fptr);
      fclose(fptr);
      fprintf(stderr, "The isf can be found in /tmp/dump.isf\n");
   }
}




/*
   FUNCTION: 		HandleSignal

   Synopsis: 
       To provide a graceful means of dying by at least saving out 
       any changes to a grammar.

   Initial purpose:
       Same as above.

   Present purpose:
       Same as above.

   Creator:	Conleth O'Connell
   Reviewer:	

   Modifications:
       DATE       WHO    REASON
       91/03/08   cso    Dump the grammar even if I don't recognize
                          the signal.

   Globals used:
       none

   Globals Modified:
       none

   Return value:	static void

   Range:		none
*/

static void
HandleSignal(sig)

int
   sig;           /* The signal needing handling */

{
   /*
    * Depending on the signal, handle it
    */
   switch (sig)
   {
   default:
      /*
       * This signal is not handled
       */
      fprintf(stderr, "Didn't match anybody\n");
      FileDump();
      break;

   case SIGSEGV:
      /*
       * This is a segmentation violation, dump the grammar
       */
      fprintf(stderr, "Received a Segmentation Violation signal\n");
      FileDump();
      break;

#ifndef linux
   case SIGBUS:
      /*
       * This is a bus error, dump the grammar
       */
      fprintf(stderr, "Received a Bus error signal\n");
      FileDump();
      break;
#endif

   case SIGHUP:
      /*
       * This signal is not handled
       */
      fprintf(stderr, "Received a HangUp signal\n");
      break;

   case SIGINT:
      /*
       * This signal is not handled
       */
      fprintf(stderr, "Received a Ctrl-C signal\n");
      break;
   }
   exit(2);
}




/*
   FUNCTION: 		InstallSignalHandlers

   Synopsis: 
       Install the signal handler for certain types of signals.

   Initial purpose:
       Same as above.

   Present purpose:
       Same as above.

   Creator:	Conleth O'Connell
   Reviewer:	

   Modifications:
       DATE       WHO    REASON

   Globals used:
       none

   Globals Modified:
       none

   Return value:	void

   Range:		none
*/

void
InstallSignalHandlers()

{
   /*
    * As the installation occurs, check for an error, inform the user
    * if installation of any of the signals have failed
    */
   if (
#ifndef linux
       (signal(SIGBUS,  HandleSignal) == SIG_ERR) ||
#endif
       (signal(SIGHUP,  HandleSignal) == SIG_ERR) ||
       (signal(SIGINT,  HandleSignal) == SIG_ERR) ||
       (signal(SIGSEGV, HandleSignal) == SIG_ERR))
   {
      fprintf(stderr, "Not all signal() handlers were installed\n");
   }
   return;
}
